@@ -14,7 +14,7 @@ class UtilsTestCase(unittest.TestCase):
     }
 
     actual = []
-    callback = lambda item, _: actual.append(item)
+    callback = lambda item, key, node: actual.append(item)
     utils.walk(data, callback)
 
     expected = ['bar', 'bar2', 'bar3', 'bar4']
@@ -44,6 +44,7 @@ class UtilsTestCase(unittest.TestCase):
         '# Bam'
     )
     fields, content = utils.parse_markdown(content)
+    print fields, content
     self.assertEqual(None, fields)
     self.assertEqual('# Bam', content)
 
