@@ -1,6 +1,7 @@
 from grow.pods import pods
 from grow.pods.collectionz import collectionz
 from grow.pods.collectionz import messages
+from grow.pods import locales
 from grow.pods import storage
 import unittest
 
@@ -28,14 +29,14 @@ class CollectionsTest(unittest.TestCase):
 
     collection = self.pod.get_collection('posts')
     documents = collection.list_documents(order_by='$published', reverse=True)
-    expected = ['newest', 'newer', 'older', 'oldest']
+    expected = ['newest-custom-slug', 'newer', 'older', 'oldest']
     self.assertListEqual(expected, [doc.slug for doc in documents])
 
   def test_list_locales(self):
     collection = self.pod.get_collection('pages')
-    locales = collection.list_locales()
-    expected = ['de', 'fr', 'it']
-    self.assertListEqual(expected, locales)
+    found_locales = collection.list_locales()
+    expected = locales.Locale.parse_codes(['de', 'en', 'fr', 'it'])
+    self.assertListEqual(expected, found_locales)
 
   def test_list_servable_documents(self):
     collection = self.pod.get_collection('pages')
@@ -49,7 +50,7 @@ class CollectionsTest(unittest.TestCase):
     doc = collection.get_doc('/content/posts/newest.md')
     self.assertEqual(doc.format, messages.Format.MARKDOWN)
     self.assertEqual('# Markdown', doc.body)
-    self.assertEqual('<h1 id="markdown">Markdown</h1>', doc.html())
+    self.assertEqual('<h1 id="markdown">Markdown</h1>', doc.html)
 
 
 if __name__ == '__main__':
