@@ -1,12 +1,14 @@
 from grow.common import markdown_extensions
 from grow.common import utils
 from grow.pods import urls
+from grow.pods import locales
 from grow.pods.collectionz import messages
 import jinja2
 import json
 import logging
 import markdown
 import os
+import copy
 from markdown.extensions import tables
 from markdown.extensions import toc
 
@@ -37,6 +39,7 @@ class Document(object):
 
   def __init__(self, pod_path, _pod, locale=None, _collection=None, body_format=None):
     utils.validate_name(pod_path)
+    self._default_locale = _pod.podspec.default_locale
     self.locale = locale or _pod.podspec.default_locale
     self.pod_path = pod_path
     self.basename = os.path.basename(pod_path)
@@ -47,15 +50,18 @@ class Document(object):
 
     self.format = messages.extensions_to_formats.get(self.ext)
     if self.format == messages.Format.MARKDOWN:
-      self.doc_storage = MarkdownDocumentStorage(self.pod_path, self.pod)
+      self.doc_storage = MarkdownDocumentStorage(
+          self.pod_path, self.pod, locale=locale, default_locale=self._default_locale)
     elif self.format == messages.Format.YAML:
-      self.doc_storage = YamlDocumentStorage(self.pod_path, self.pod)
+      self.doc_storage = YamlDocumentStorage(
+          self.pod_path, self.pod, locale=locale, default_locale=self._default_locale)
     else:
       formats = messages.extensions_to_formats.keys()
       text = 'Basename "{}" does not have a valid extension. Valid formats are: {}'
       raise BadFormatError(text.format(self.basename, ', '.join(formats)))
 
     self.fields = self.doc_storage.fields
+    self.tagged_fields = self.doc_storage.tagged_fields
 
   def __repr__(self):
     if self.locale:
@@ -68,6 +74,11 @@ class Document(object):
   def __ne__(self, other):
     return self.pod_path != other.pod_path or self.pod != other.pod
 
+  def __getattr__(self, name):
+    if name in self.fields:
+      return self.fields[name]
+    return object.__getattribute__(self, name)
+
   @property
   def url(self):
     path = self.get_serving_path()
@@ -96,7 +107,8 @@ class Document(object):
   def titles(self, title_name=None):
     if title_name is None:
       return self.title
-    return self.fields.get('$titles', {}).get(title_name, self.title)
+    titles = self.fields.get('$titles', {})
+    return titles.get(title_name, self.title)
 
   @property
   def published(self):
@@ -123,8 +135,8 @@ class Document(object):
 
   def get_path_format(self):
     val = None
-    if self.locale:
-      if '$localization' in self.fields and self.fields['$localization']['path']:
+    if self.locale and self._default_locale and self.locale != self._default_locale:
+      if '$localization' in self.fields and 'path' in self.fields['$localization']:
         val = self.fields['$localization']['path']
       elif self.collection.localization:
         val = self.collection.localization['path']
@@ -153,7 +165,7 @@ class Document(object):
       return path_format.format(**{
           'doc': self,
           'parent': self.parent if self.parent else DummyDict(),
-          'locale': self.locale,
+          'locale': str(self.locale),
           'podspec': self.pod.get_podspec(),
           'base': os.path.splitext(os.path.basename(self.pod_path))[0],
           'slug': self.slug,
@@ -162,12 +174,16 @@ class Document(object):
       logging.error('Error with path format: {}'.format(path_format))
       raise
 
+  @property
+  def locales(self):
+    return self.list_locales()
+
   def list_locales(self):
     if '$localization' in self.fields:
-      if self.fields['$localization'].get('use_podspec_locales'):
-        return self.pod.list_locales()
-      return self.fields['$localization']['locales']
-    return self.collection.list_locales()
+      if 'locales' in self.fields['$localization']:
+        codes = self.fields['$localization']['locales']
+    codes = self.collection.list_locales()
+    return locales.Locale.parse_codes(codes)
 
   @property
   @utils.memoize
@@ -190,11 +206,6 @@ class Document(object):
             and isinstance(other, Document)
             and self.pod_path == other.pod_path)
 
-  def __getattr__(self, name):
-    if name in self.fields:
-      return self.fields[name]
-    return object.__getattribute__(self, name)
-
   def next(self, docs=None):
     # TODO(jeremydw): Verify items is a list of docs.
     if docs is None:
@@ -252,13 +263,19 @@ class Document(object):
     return message
 
 
+# TODO(jeremydw): This needs a lot of cleanup. :)
+
 class BaseDocumentStorage(object):
 
-  def __init__(self, pod_path, pod):
+  def __init__(self, pod_path, pod, locale=None, default_locale=None):
+    # TODO(jeremydw): Only accept Locale objects, not strings.
+    self.default_locale = default_locale
+    self.locale = str(locale) if isinstance(locale, basestring) else locale
     self.pod_path = pod_path
     self.pod = pod
     self.content = None
     self.fields = {}
+    self.tagged_fields = {}
     self.builtins = None
     self.body = None
     try:
@@ -285,7 +302,10 @@ class YamlDocumentStorage(BaseDocumentStorage):
     fields, body = utils.parse_yaml(content, path=path)
     self.content = content
     self.fields = fields or {}
+    self.tagged_fields = {}
     self.body = body
+    self.tagged_fields = copy.deepcopy(fields)
+    fields = untag_fields(fields)
 
 
 class MarkdownDocumentStorage(BaseDocumentStorage):
@@ -293,10 +313,13 @@ class MarkdownDocumentStorage(BaseDocumentStorage):
   def load(self):
     path = self.pod_path
     content = self.pod.read_file(path)
-    fields, body = utils.parse_markdown(content, path=path)
+    fields, body = utils.parse_markdown(
+        content, path=path, locale=self.locale, default_locale=self.default_locale)
     self.content = content
     self.fields = fields or {}
     self.body = body
+    self.tagged_fields = copy.deepcopy(fields)
+    fields = untag_fields(fields)
 
   def html(self, doc, params=None):
     val = self.body
@@ -315,3 +338,13 @@ class MarkdownDocumentStorage(BaseDocumentStorage):
         template = jinja2.Template(val)
         val = template.render(params)
     return val
+
+
+def untag_fields(fields):
+  def callback(item, key, node):
+    if not isinstance(key, basestring):
+      return
+    if key.endswith('@'):
+      node[key[0:(len(key) - 1)]] = node.pop(key)
+  utils.walk(fields, callback)
+  return fields
