@@ -47,12 +47,7 @@ class PageController(base.BaseController):
   @property
   @utils.memoize
   def _template_env(self):
-    _template_loader = self.pod.storage.JinjaLoader(self.pod.root)
-    env = jinja2.Environment(
-        loader=_template_loader, autoescape=True, trim_blocks=True,
-        extensions=['jinja2.ext.i18n'])
-    env.filters['markdown'] = tags.markdown_filter
-    return env
+    return self.pod.get_template_env()
 
   def _install_translations(self, ll):
     if ll is None:
@@ -74,20 +69,26 @@ class PageController(base.BaseController):
     ll = self.locale
     self._install_translations(ll)
     template = self._template_env.get_template(self.view.lstrip('/'))
+    context = {}
     context = {
         'categories': lambda *args, **kwargs: tags.categories(*args, _pod=self.pod, **kwargs),
-        'cc': self.cc,
-        'doc': self.document,
         'docs': lambda *args, **kwargs: tags.docs(*args, _pod=self.pod, **kwargs),
-        'get_doc': lambda *args, **kwargs: tags.get_doc(*args, _pod=self.pod, **kwargs),
-        'is_active': lambda doc: tags.is_active(doc, self.document),
+        'doc': lambda *args, **kwargs: tags.get_doc(*args, _pod=self.pod, **kwargs),
+        'static': lambda path: tags.static(path, _pod=self.pod),
+        'breadcrumb': lambda *args, **kwargs: tags.breadcrumb(*args, _pod=self.pod, **kwargs),
+        'nav': lambda *args, **kwargs: tags.nav(*args, _pod=self.pod, **kwargs),
+        'cc': self.cc,
         'll': self.ll,
         'params': self.route_params,
         'pod': self.pod,
-        'static': lambda path: tags.static(path, _pod=self.pod),
+        'url': lambda *args, **kwargs: tags.url(*args, _pod=self.pod, **kwargs),
     }
     try:
-      return template.render({'g': context})
+      return template.render({
+          'g': context,
+          'doc': self.document,
+          'podspec': self.pod.get_podspec(),
+      })
     except Exception as e:
       text = 'Error building {}: {}'
       logging.exception(e)
