@@ -20,17 +20,21 @@ class RoutesTest(unittest.TestCase):
         '/',
         '/about/',
         '/contact-us/',
+        '/intro/',
         '/de/about/',
         '/de/contact/',
         '/de/home/',
+        '/de/intro/',
         '/fr/about/',
         '/fr/contact/',
         '/fr/home/',
+        '/fr/intro/',
         '/it/about/',
         '/it/contact/',
         '/it/home/',
+        '/it/intro/',
         '/post/newer/',
-        '/post/newest/',
+        '/post/newest-custom-slug/',
         '/post/older/',
         '/post/oldest/',
         '/public/file.txt',
@@ -38,6 +42,7 @@ class RoutesTest(unittest.TestCase):
         '/public/main.min.js',
     ]
     result = self.pod.routes.list_concrete_paths()
+    print result
     self.assertItemsEqual(expected, result)
 
 
